@@ -11,13 +11,13 @@
 /* Returns how many mails are available on POP3-server "h" with username "n" and password "e"
  * The server-name may be given with or without port-number in form "host:port". 
  */
-int pop3_check(char *h, char* n, char* e);
+int pop3_check(const char *h, const char* n, const char* e);
 
 /* Returns how many mails are available on IMAP-server "h" with username "n" and password "e"
  * Hi: unseen/recent; Lo: total
  * The server-name may be given with or without port-number in form "host:port".
  */
-int imap_check(char *h, char* n, char* e);
+int imap_check(const char *h, const char* n, const char* e);
 
 #endif
 
