@@ -27,6 +27,7 @@
 #include "scroll-menu.h"
 #include "gwmh.h"
 #include "tasklist_icon.h"
+#include "scroll-menu.h"
 
 #define SMALL_ICON_SIZE 20
 
@@ -38,8 +39,6 @@ extern GtkTooltips *panel_tooltips;
 static void foobar_widget_class_init	(FoobarWidgetClass	*klass);
 static void foobar_widget_init		(FoobarWidget		*foo);
 static void foobar_widget_realize	(GtkWidget		*w);
-static gboolean foobar_widget_configure_event (GtkWidget        *w,
-					       GdkEventConfigure *event);
 static void foobar_widget_destroy	(GtkObject		*o);
 static void foobar_widget_size_allocate	(GtkWidget		*w,
 					 GtkAllocation		*alloc);
@@ -92,7 +91,6 @@ foobar_widget_class_init (FoobarWidgetClass *klass)
 	object_class->destroy = foobar_widget_destroy;
 
 	widget_class->realize = foobar_widget_realize;
-	widget_class->configure_event = foobar_widget_configure_event;
 	widget_class->size_allocate = foobar_widget_size_allocate;
 	widget_class->enter_notify_event = foobar_enter_notify;
 	widget_class->leave_notify_event = foobar_leave_notify;
@@ -651,21 +649,6 @@ foobar_widget_realize (GtkWidget *w)
 	setup_task_menu (FOOBAR_WIDGET (w));
 }
 
-static gboolean
-foobar_widget_configure_event (GtkWidget *w, GdkEventConfigure *event)
-{
-	g_return_val_if_fail (IS_FOOBAR_WIDGET (w), FALSE);
-
-	if (event->x != 0 ||
-	    event->y != 0)
-		gdk_window_move (w->window, 0, 0);
-
-	if (GTK_WIDGET_CLASS (parent_class)->configure_event != NULL)
-		return GTK_WIDGET_CLASS (parent_class)->configure_event (w, event);
-	else
-		return FALSE;
-}
-
 static void
 programs_menu_to_display(GtkWidget *menu)
 {
@@ -687,7 +670,7 @@ programs_menu_to_display(GtkWidget *menu)
 static void
 set_the_task_submenu (FoobarWidget *foo, GtkWidget *item)
 {
-	foo->task_menu = gtk_menu_new ();
+	foo->task_menu = scroll_menu_new ();
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), foo->task_menu);
 	/*g_message ("setting...");*/
 }
@@ -865,7 +848,7 @@ task_notify (gpointer data, GwmhTask *task,
 			add_task (task, foo);
 		break;
 	case GWMH_NOTIFY_DESTROY:
-#warning Whoa; leak?
+		/* FIXME: Whoa; leak? */
 		if (foo->tasks != NULL) {
 			item = g_hash_table_lookup (foo->tasks, task);
 			if (item) {
